@@ -14,6 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import base64
 from datetime import timedelta
 import logging
 
@@ -27,18 +28,21 @@ from django.utils.translation import ugettext as _  # noqa
 from django.utils.translation import ugettext_lazy
 from django.views.generic import View  # noqa
 
+from horizon import exceptions
 from horizon import forms
 from horizon import tables
+from horizon.utils import functions as utils
 
 from monitoring.alarms import constants
 from monitoring.alarms import forms as alarm_forms
 from monitoring.alarms import tables as alarm_tables
 from monitoring import api
 
+from openstack_dashboard import policy
+
 LOG = logging.getLogger(__name__)
 SERVICES = getattr(settings, 'MONITORING_SERVICES', [])
 
-LIMIT = 10
 PREV_PAGE_LIMIT = 100
 
 
@@ -80,7 +84,7 @@ def get_status(alarms):
     status_index = 0
     for a in alarms:
         severity = alarm_tables.show_severity(a)
-        severity_index = index_by_severity[severity]
+        severity_index = index_by_severity.get(severity, None)
         status_index = max(status_index, severity_index)
     return priorities[status_index]['status']
 
@@ -133,11 +137,12 @@ class AlarmServiceView(tables.DataTableView):
         if page_offset is None:
             page_offset = 0
 
+        limit = utils.get_page_size(self.request)
         if self.service == default_service:
             try:
                 results = api.monitor.alarm_list(self.request, page_offset,
-                                                 LIMIT)
-                paginator = Paginator(results, LIMIT)
+                                                 limit)
+                paginator = Paginator(results, limit)
                 contacts = paginator.page(1)
             except EmptyPage:
                 contacts = paginator.page(paginator.num_pages)
@@ -157,16 +162,21 @@ class AlarmServiceView(tables.DataTableView):
                 return results
             else:
                 try:
+                    if self.service[:3] == 'b64':
+                        name, value = self.service.split(":")
+                        self.service = base64.urlsafe_b64decode(str(value))
                     results = api.monitor.alarm_list_by_dimension(self.request,
                                                                   self.service,
                                                                   page_offset,
-                                                                  LIMIT)
+                                                                  limit)
                 except Exception:
                     messages.error(self.request, _("Could not retrieve alarms"))
                     results = []
                 return results
 
     def get_context_data(self, **kwargs):
+        if not policy.check((('monitoring', 'monitoring:monitoring'), ), self.request):
+            raise exceptions.NotAuthorized()
         context = super(AlarmServiceView, self).get_context_data(**kwargs)
         results = []
         num_results = 0  # make sure variable is set
@@ -181,14 +191,14 @@ class AlarmServiceView(tables.DataTableView):
             prev_page_stack = []
         else:
             page_offset = int(page_offset)
-
+        limit = utils.get_page_size(self.request)
         if self.service == 'all':
             try:
-                # To judge whether there is next page, get LIMIT + 1
+                # To judge whether there is next page, get limit + 1
                 results = api.monitor.alarm_list(self.request, page_offset,
-                                                 LIMIT + 1)
+                                                 limit + 1)
                 num_results = len(results)
-                paginator = Paginator(results, LIMIT)
+                paginator = Paginator(results, limit)
                 results = paginator.page(1)
             except EmptyPage:
                 results = paginator.page(paginator.num_pages)
@@ -204,13 +214,13 @@ class AlarmServiceView(tables.DataTableView):
                     results = []
             else:
                 try:
-                    # To judge whether there is next page, get LIMIT + 1
+                    # To judge whether there is next page, get limit + 1
                     results = api.monitor.alarm_list_by_dimension(self.request,
                                                                   self.service,
                                                                   page_offset,
-                                                                  LIMIT + 1)
+                                                                  limit + 1)
                     num_results = len(results)
-                    paginator = Paginator(results, LIMIT)
+                    paginator = Paginator(results, limit)
                     results = paginator.page(1)
                 except EmptyPage:
                     results = paginator.page(paginator.num_pages)
@@ -221,10 +231,10 @@ class AlarmServiceView(tables.DataTableView):
         context["contacts"] = results
         context["service"] = self.service
 
-        if num_results < LIMIT + 1:
+        if num_results < limit + 1:
             context["page_offset"] = None
         else:
-            context["page_offset"] = page_offset + LIMIT
+            context["page_offset"] = page_offset + limit
 
         if page_offset in prev_page_stack:
             index = prev_page_stack.index(page_offset)
@@ -288,13 +298,13 @@ class AlarmHistoryView(tables.DataTableView):
             ts_mode = alarm_history_default_ts_format
         if not page_offset:
             page_offset = 0
-
+        limit = utils.get_page_size(self.request)
         try:
             results = api.monitor.alarm_history(self.request,
                                                 object_id,
                                                 page_offset,
-                                                LIMIT)
-            paginator = Paginator(results, LIMIT)
+                                                limit)
+            paginator = Paginator(results, limit)
             contacts = paginator.page(1)
         except EmptyPage:
             contacts = paginator.page(paginator.num_pages)
@@ -312,6 +322,8 @@ class AlarmHistoryView(tables.DataTableView):
         return []
 
     def get_context_data(self, **kwargs):
+        if not policy.check((('monitoring', 'monitoring:monitoring'), ), self.request):
+            raise exceptions.NotAuthorized()
         context = super(AlarmHistoryView, self).get_context_data(**kwargs)
 
         object_id = kwargs['id']
@@ -329,7 +341,7 @@ class AlarmHistoryView(tables.DataTableView):
         contacts = []
         prev_page_stack = []
         page_offset = self.request.GET.get('page_offset')
-
+        limit = utils.get_page_size(self.request)
         if 'prev_page_stack' in self.request.session:
             prev_page_stack = self.request.session['prev_page_stack']
 
@@ -337,11 +349,11 @@ class AlarmHistoryView(tables.DataTableView):
             page_offset = 0
             prev_page_stack = []
         try:
-            # To judge whether there is next page, get LIMIT + 1
+            # To judge whether there is next page, get limit + 1
             results = api.monitor.alarm_history(self.request, object_id, page_offset,
-                                                LIMIT + 1)
+                                                limit + 1)
             num_results = len(results)
-            paginator = Paginator(results, LIMIT)
+            paginator = Paginator(results, limit)
             contacts = paginator.page(1)
         except EmptyPage:
             contacts = paginator.page(paginator.num_pages)
@@ -355,7 +367,7 @@ class AlarmHistoryView(tables.DataTableView):
         context['timestamp_selected'] = ts_mode or ''
         context['timestamp_offset'] = ts_offset or 0
 
-        if num_results < LIMIT + 1:
+        if num_results < limit + 1:
             context["page_offset"] = None
         else:
             context["page_offset"] = contacts.object_list[-1]["id"]
@@ -381,6 +393,8 @@ class AlarmFilterView(forms.ModalFormView):
     form_class = alarm_forms.CreateAlarmForm
 
     def get_context_data(self, **kwargs):
+        if not policy.check((('monitoring', 'monitoring:monitoring'), ), self.request):
+            raise exceptions.NotAuthorized()
         context = super(AlarmFilterView, self).get_context_data(**kwargs)
         context["cancel_url"] = self.get_success_url()
         context["action_url"] = reverse(constants.URL_PREFIX + 'alarm_filter',
